@@ -1,6 +1,7 @@
 /* ============================================================
 * Falkon - Qt web browser
 * Copyright (C) 2010-2016 David Rosca <nowrep@gmail.com>
+* Copyright (C) 2024 Juraj Oravec <jurajoravec@mailo.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -15,50 +16,17 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ============================================================ */
+
 #include "progressbar.h"
 
-#include <QStylePainter>
-#include <QStyleOptionProgressBar>
 
 ProgressBar::ProgressBar(QWidget* parent)
-    : QWidget(parent)
-    , m_value(0)
-    , m_lastPaintedValue(-1)
+    : QProgressBar(parent)
 {
     setMinimumSize(130, 16);
     setMaximumSize(150, 16);
-}
 
-void ProgressBar::setValue(int value)
-{
-    m_value = value;
-    if (m_lastPaintedValue != m_value) {
-        update();
-    }
-}
-
-void ProgressBar::initStyleOption(QStyleOptionProgressBar* option)
-{
-    if (!option) {
-        return;
-    }
-
-    option->initFrom(this);
-    option->minimum = 0;
-    option->maximum = 100;
-    option->progress = m_value;
-    option->textAlignment = Qt::AlignLeft;
-    option->textVisible = false;
-}
-
-void ProgressBar::paintEvent(QPaintEvent*)
-{
-    QStylePainter paint(this);
-
-    QStyleOptionProgressBar opt;
-    initStyleOption(&opt);
-
-    paint.drawControl(QStyle::CE_ProgressBar, opt);
-
-    m_lastPaintedValue = m_value;
+    setMinimum(0);
+    setMaximum(100);
+    setTextVisible(false);
 }
